@@ -27,7 +27,7 @@
 #include <powerdevilpowermanagement.h>
 
 #include <powerdevil_debug.h>
-#include <TabletModeWatcher>
+#include <Kirigami/TabletModeWatcher>
 
 #include <QCheckBox>
 #include <QFormLayout>
@@ -51,9 +51,7 @@
 #include <Solid/Battery>
 #include <Solid/Device>
 
-K_PLUGIN_FACTORY(PowerDevilProfilesKCMFactory,
-                 registerPlugin<EditPage>();
-                )
+K_PLUGIN_CLASS_WITH_JSON(EditPage, "kcm_powerdevilprofilesconfig.json")
 
 EditPage::EditPage(QWidget *parent, const QVariantList &args)
         : KCModule(parent, args)
